@@ -1,10 +1,10 @@
 #!/usr/bin/perl -w
 
-# $Id: clamav-update.pl,v 1.47 2010/04/24 02:27:52 okamura Exp $
+# $Id: clamav-update.pl,v 1.20 2007/03/07 09:33:29 okamura Exp $
 
 =head1 NAME
 
-clamav-update.pl - auto updater for ClamAV
+clamav-update.pl - auto update clamav
 
 =head1 SYNOPSIS
 
@@ -14,44 +14,10 @@ clamav-update.pl - auto updater for ClamAV
 
 =head1 DESCRIPTION
 
-B<clamav-update.pl> is automatic customizable updater for general software.
-Mainly, It is developed to update Clam AntiVirus.
-Default configuration is designed for ClamAV Engine for ClamXav user
-on Mac OS X.
+B<clamav-update.pl> update clamav for ClamXav user.
 
-B<clamav-update.pl> acts as:
-
-1. Check execution situation for security.
-
-Only root can execute B<clamav-update.pl>.
-If someone execute it with other user's privilege, it show warning and quit.
-Don't add setuid to it.
-If do so, it can not be executed.
-
-2. Analizes arguments and loads configurations.
-
-Default configuration file is F</usr/local/clamXav/etc/clamav-update.conf>.
-
-3. Compares newest version and current version of target.
-
-B<clamav-update.pl> will continue
-if and only if newest version is newer than current version.
-The method of getting the version strings and the method of comparing them
-are defined by the configuration.
-
-4. Executes phases defined on configuration files.
-
-If errors are detected in any phase, execute commands set defined as roll back
-in that phase. and return error.
-
-In other words, we assumes only followings.
-
-  + root uses clamav-update.pl.
-  + clamav-update.pl updates target software,
-    if newer version of it is released. 
-
-Method of updating is given from
-your configuration file or command line options.
+But it isn't only for them.
+See http://clamav-update.sourceforge.jp/docs/clamav-update/index.html
 
 =cut
 
@@ -146,8 +112,28 @@ sub _Fdlog {
 
 sub IsMasked {
 	my	($priority) = @_;
+	my	$numpri = undef;
+	my	$numfac = undef;
 
-	return setlogmask(0) < Sys::Syslog::LOG_UPTO(Sys::Syslog::xlate($priority));
+	foreach (split(/\W+/, $priority, 2)) {
+		my	$num = Sys::Syslog::xlate($_);
+
+		if (/^kern$/ or $num < 0) {
+			croak "invalid level/facility: $_";
+		}
+		elsif ($num <= &Sys::Syslog::LOG_PRIMASK) {
+			croak "too many levels given: $_"	if defined($numpri);
+			$numpri = $num;
+			return 1	unless (
+				Sys::Syslog::LOG_MASK($numpri) & $Sys::Syslog::maskpri);
+		}
+		else {
+			croak "too many facilities given: $_" if defined($numfac);
+			$numfac = $num;
+		}
+	}
+
+	return 0;
 }
 
 sub SetEnv {
@@ -201,11 +187,7 @@ sub PrepareLogging {
 
 	# setlogsock
 	if (ref($Setting{logging}->{setlogsock}) eq 'GLOB') {
-		my	$currentSelected = select $Setting{logging}->{setlogsock};
-
 		*Log = *_Fdlog;
-		$| = 1;
-		select $currentSelected;
 	}
 	else {
 		if (ref($Setting{logging}->{setlogsock}) eq 'ARRAY') {
@@ -233,15 +215,6 @@ sub PrepareLogging {
 	}
 }
 
-sub CloseLog {
-	if ($SyslogOpened) {
-		closelog();
-	}
-	elsif (*Log eq *_Fdlog) {
-		close $Setting{logging}->{setlogsock};
-	}
-}
-
 sub LoadConfig {
 	my	($path) = @_;
 
@@ -513,18 +486,6 @@ sub CheckSecurity {
 	return $ok; 
 }
 
-sub StringFromTemplateHash {
-	my	(%template) = @_;
-	my	$string = $template{template};
-	
-	while (my ($name, $value) = each %{$template{params}}) {
-		$value = ${$value};
-		$string =~ s/\Q$name\E/$value/g;
-	}
-
-	return $string;
-}
-
 #### Build-In Phase Specifier ####
 
 # General
@@ -537,9 +498,9 @@ sub StringFromTemplateHash {
 #		download file name format is xxxx-1.2.3.tar.gz
 #		extracted directory name format is xxxx-1.2.3
 #	SAMPLE CONFIGUREATION:
-#		$Setting{version}->{latest}->{command} = <method of your software>;
+#		$Setting{version}->{latest}->{command} = <mthod of your software>;
 #		$Setting{version}->{latest}->{regexp} = qr/regexp for above/;
-#		$Setting{version}->{current}->{command} = <method of your software>;
+#		$Setting{version}->{current}->{command} = <mthod of your software>;
 #		$Setting{version}->{current}->{regexp} = qr/regexp for above/;
 #		$Setting{option}->{src} = '<Base URL for your software>';
 #		$Setting{option}->{name} = '<Name of your software>';
@@ -554,26 +515,13 @@ sub PhaseSpecifier4General {
 	# working directory (not specified)
 	$Phase{download}->{workdir} = undef;
 	# command sequence
-	if (ref($Setting{option}->{src}) eq 'HASH') {
-		my	$src = StringFromTemplateHash(%{$Setting{option}->{src}});
-
-		$Phase{download}->{method} = [
-			# curl --silent --location -o DST/NAME-VERSION.EXT SRC
-			['curl', '--silent', '--location', '-o',
-				"$Setting{option}->{dst}/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}",
-				$src
-			],
-		];
-	}
-	else {
-		$Phase{download}->{method} = [
-			# curl --silent --location -o DST/NAME-VERSION.EXT SRC/NAME-VERSION.EXT
-			['curl', '--silent', '--location', '-o',
-				"$Setting{option}->{dst}/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}",
-				"$Setting{option}->{src}/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}"
-			],
-		];
-	}
+	$Phase{download}->{method} = [
+		# curl --silent -o DST/NAME-VERSION.EXT SRC/NAME-VERSION.EXT
+		['curl', '--silent', '-o',
+			"$Setting{option}->{dst}/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}",
+			"$Setting{option}->{src}/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}"
+		],
+	];
 	# rollback command sequence.
 	$Phase{download}->{rollback} = [
 		# rm -f DST/NAME-VERSION.EXT
@@ -643,10 +591,10 @@ sub PhaseSpecifier4General {
 # ClamAV for ClamXav
 #	1. download gzip compressed tar file.
 #	2. extract it.
-#	3. do ./configure --prefix=/usr/local/clamXav
+#	3. do ./configure --prefix=/usr/local
 #	4. do make
 #	5. do make install
-#	6. change owner, group and permission
+#	6. change owner, group, permission
 sub PhaseSpecifier4ClamAV4ClamXav {
 	#### Initialization ####
 	# use PhaseSpecifier4General as base.
@@ -664,15 +612,15 @@ sub PhaseSpecifier4ClamAV4ClamXav {
 	push @{$Phase{install}->{method}}, (
 		[qw(install -d -o root -g admin -m 0775 /usr/local/clamXav)],
 		[qw(chown -R root:admin /usr/local/clamXav/etc)],
-		[qw(find /usr/local/clamXav/etc -type d -exec chmod 0775 {} ;)],
-		[qw(find /usr/local/clamXav/etc -type f -exec chmod 0664 {} ;)],
+		[qw(find /usr/local/clamXav/etc -type d -exec chmod 0775 {} \;)],
+		[qw(find /usr/local/clamXav/etc -type f -exec chmod 0664 {} \;)],
 		[qw(chown -R root:admin /usr/local/clamXav/bin)],
 		[qw(chmod -R 0755 /usr/local/clamXav/bin)],
 		[qw(chown clamav /usr/local/clamXav/bin/freshclam)],
 		[qw(chmod u+s /usr/local/clamXav/bin/freshclam)],
 		[qw(chown -R clamav:clamav /usr/local/clamXav/share/clamav)],
-		[qw(find /usr/local/clamXav/share/clamav -type d -exec chmod 0775 {} ;)],
-		[qw(find /usr/local/clamXav/share/clamav -type f -exec chmod 0664 {} ;)],
+		[qw(find /usr/local/clamXav/share/clamav -type d -exec chmod 0775 {} \;)],
+		[qw(find /usr/local/clamXav/share/clamav -type f -exec chmod 0664 {} \;)],
 		[qw(touch /usr/local/clamXav/share/clamav/freshclam.log)],
 		[qw(chmod 0664 /usr/local/clamXav/share/clamav/freshclam.log)],
 	);
@@ -680,7 +628,7 @@ sub PhaseSpecifier4ClamAV4ClamXav {
 	1;
 }
 
-# pkg on dmg file for Mac OS X
+# pkg on dmg file
 #	1. download dmg file.
 #	2. attach it.
 #	3. install from pkg file.
@@ -689,7 +637,7 @@ sub PhaseSpecifier4ClamAV4ClamXav {
 #		dmg file name format is xxxx-1.2.3.dmg
 #		pkg file name format is xxxx-1.2.3.pkg
 #	SAMPLE CONFIGUREATION:
-#		$Setting{version}->{latest}->{command} = <method of your software>;
+#		$Setting{version}->{latest}->{command} = <mthod of your software>;
 #		$Setting{version}->{latest}->{regexp} = qr/regexp for above/;
 #		$Setting{version}->{current}->{command} = sub {
 #			my  $newestVer;
@@ -727,34 +675,33 @@ sub PhaseSpecifier4PkgOnDmg {
 	$Phase{attach}->{workdir} = undef;
 	$Phase{attach}->{method} = [
 		['hdiutil', 'attach',
-			'-mountpoint', $Setting{option}->{dst},
 			"$Setting{option}->{dst}/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}"
 		],
 	];
 	$Phase{attach}->{rollback} = [
-		['hdiutil', 'detach', '-force',
-			$Setting{option}->{dst}
+		['hdiutil', 'detach',
+			"/Volumes/$Setting{option}->{name}-$LatestVersion"
 		],
 	];
 
 	$Phase{install}->{workdir} = undef;
 	$Phase{install}->{method} = [
 		['installer', '-pkg',
-			"$Setting{option}->{dst}/$Setting{option}->{name}-$LatestVersion.pkg",
+			"/Volumes/$Setting{option}->{name}-$LatestVersion/$Setting{option}->{name}-$LatestVersion.pkg",
 			'-target', '/'
 		],
 	];
 	$Phase{install}->{rollback} = [
-		['hdiutil', 'detach', '-force',
-			$Setting{option}->{dst}
+		['hdiutil', 'detach',
+			"/Volumes/$Setting{option}->{name}-$LatestVersion"
 		],
 	];
 
 	$Phase{detach} = {};
 	$Phase{detach}->{workdir} = undef;
 	$Phase{detach}->{method} = [
-		['hdiutil', 'detach', '-force',
-			$Setting{option}->{dst}
+		['hdiutil', 'detach',
+			"/Volumes/$Setting{option}->{name}-$LatestVersion"
 		],
 	];
 	$Phase{detach}->{rollback} = [
@@ -768,7 +715,7 @@ sub PhaseSpecifier4PkgOnDmg {
 #	2. extract it.
 #	3. copy files
 #	SAMPLE CONFIGURATION:
-#		$Setting{version}->{latest}->{command} = [qw(curl --silent --location http://clamav-update.sourceforge.jp/release/clamav-update-2/version.txt)];
+#		$Setting{version}->{latest}->{command} = [qw(curl --silent http://clamav-update.sourceforge.jp/release/clamav-update-2/version.txt)];
 #		$Setting{version}->{latest}->{regexp} = qr/^(\d+(?:\.\d+)*)\s*$/;
 #		$Setting{version}->{current}->{command} = [qw(clamav-update.pl --version)];
 #		$Setting{version}->{current}->{regexp} = qr/^(?s-im)clamav-update\.pl v(\d+(?:\.\d+)*)\s+.*$/;
@@ -778,7 +725,7 @@ sub PhaseSpecifier4PkgOnDmg {
 #   		'http://osdn.dl.sourceforge.jp/clamav-update'     - Tokyo Japan: OSDN Japan
 #   		'http://keihanna.dl.sourceforge.jp/clamav-update' - Keihanna Japan: Kansai Science City Internet Community
 #   		'http://qgpop.dl.sourceforge.jp/clamav-update'    - Fukuoka Japan: Kyushu GigaPOP Project
-#		$Setting{option}->{limit}->{version} = '3';
+#		$Setting->{option}->{limit}->{version} = '3';
 sub PhaseSpecifier4ClamavUpdate4ClamXav {
 	PhaseSpecifier4General();
 	delete $Phase{build};
@@ -787,13 +734,13 @@ sub PhaseSpecifier4ClamavUpdate4ClamXav {
 		sub {
 			my	$releaseID;
 	
-			$releaseID = ReadCommandResult(qw(curl --silent --location http://clamav-update.sourceforge.jp/release/clamav-update-2/release_id.txt));
+			$releaseID = ReadCommandResult(qw(curl --silent http://clamav-update.sourceforge.jp/release/clamav-update-2/release_id.txt));
 			return 0	unless (defined($releaseID));
 			chomp $releaseID;
 			Log 'debug', 'release ID is %s', $releaseID;
 
 			return DoCommand(
-				'curl', '--silent', '--location', '-o',
+				'curl', '--silent', '-o',
 				"$Setting{option}->{dst}/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}",
 				"$Setting{option}->{src}/$releaseID/$Setting{option}->{name}-$LatestVersion.$Setting{option}->{ext}"
 			);
@@ -817,7 +764,7 @@ sub PhaseSpecifier4ClamavUpdate4ClamXav {
 #	2. extract it.
 #	3. copy files
 #	SAMPLE CONFIGURATION:
-#		$Setting{version}->{latest}->{command} = [qw(curl --silent --location http://clamav-update.sourceforge.jp/release/clamav-update-2/version.txt)];
+#		$Setting{version}->{latest}->{command} = [qw(curl --silent http://clamav-update.sourceforge.jp/release/clamav-update-2/version.txt)];
 #		$Setting{version}->{latest}->{regexp} = qr/^(\d+(?:\.\d+)*)\s*$/;
 #		$Setting{version}->{current}->{command} = [qw(clamav-update.pl --version)];
 #		$Setting{version}->{current}->{regexp} = qr/^(?s-im)clamav-update\.pl v(\d+(?:\.\d+)*)\s+.*$/;
@@ -828,15 +775,15 @@ sub PhaseSpecifier4ClamavUpdate4ClamXav {
 #   		'http://osdn.dl.sourceforge.jp/clamav-update'     - Tokyo Japan: OSDN Japan
 #   		'http://keihanna.dl.sourceforge.jp/clamav-update' - Keihanna Japan: Kansai Science City Internet Community
 #   		'http://qgpop.dl.sourceforge.jp/clamav-update'    - Fukuoka Japan: Kyushu GigaPOP Project
-#		$Setting{option}->{limit}->{version} = '3';
+#		$Setting->{option}->{limit}->{version} = '3';
 sub PhaseSpecifier4ClamavUpdate {
 	PhaseSpecifier4ClamavUpdate4ClamXav();
 
 	$Phase{install}->{method} = [
-		[qw(install -bp -o 0 -g 0 -m 0755 clamav-update.pl
+		[qw(install -bp -o root -g root -m 0755 clamav-update.pl
 			/usr/local/bin/clamav-update.pl
 		)],
-		[qw(install -bp -o 0 -g 0 -m 0664 clamav-update-update.conf
+		[qw(install -bp -o root -g root -m 0664 clamav-update-update.conf
 			/usr/local/etc/clamav-update-update.conf
 		)],
 	];
@@ -848,7 +795,7 @@ sub PhaseSpecifier4ClamavUpdate {
 #-------------------------------------------------------------------------------
 # グローバル変数初期値
 #-------------------------------------------------------------------------------
-$Version = 'clamav-update.pl v2.2.7';
+$Version = 'clamav-update.pl v2.1';
 
 %ErrorCode = (
 	arguments		=> 1,
@@ -901,6 +848,7 @@ $SyslogOpened = 0;
 		},
 	},
 	option	=> {
+		src		=> 'http://jaist.dl.sourceforge.net/sourceforge/clamav',
 		dst		=> tempdir(CLEANUP => 1),
 		name	=> 'clamav',
 		ext		=> 'tar.gz',
@@ -915,14 +863,6 @@ $SyslogOpened = 0;
 		specifier	=> undef,
 	},
 );
-$Setting{option}->{src} = {
-	template	=> 'http://jaist.dl.sourceforge.net/project/${NAME}/${NAME}/${VERSION}/${NAME}-${VERSION}.${EXT}',
-	params		=> {
-		'${NAME}'		=> \$Setting{option}->{name},
-		'${VERSION}'	=> \$LatestVersion,
-		'${EXT}'		=> \$Setting{option}->{ext},
-	},
-};
 
 %Phase = ();
 
@@ -950,112 +890,51 @@ $Setting{option}->{src} = {
 
 =item -h|--help
 
-Show manual of B<clamav-update.pl> to standard output.
-You can use perldoc instead of -h option to see manual.
-We recommend perldoc's one.
+Display help.
 
 =item -V|--version
 
-Show version of B<clamav-update.pl> to standard output
+Display version.
 
-=item -c I<filepath> | --config I<filepath>
-| -c=I<filepath> | --config=I<filepath>
+=item -c|--config I<filepath>
 
-Read config_file as configuration file.
-Default value is F</usr/local/clamXav/etc/clamav-update.conf>.
+Set the configuration file to I<filepath>.
+DEFAULT: /usr/local/clamXav/etc/clamav-update.conf
 
 =item -f|--force
 
-Force to install. Change string of current version of the software to empty.
+Force install latest version.
 
-This is for forcing to install but is depends of how to get latest version info
-and definition of comparing version function.
-This correspond to C<$Setting{option}-E<gt>{force}>.
+=item -s I<donwload_from> | --src I<donwload_from>
 
-=item -s I<download_from> | --src I<download_from>
--s=I<download_from> | --src=I<download_from>
-
-Specify base URL as I<download_from> for downloading target software.
-Default value is F<http://osdn.dl.sourceforge.jp/clamav-update>.
-
-B<clamav-update.pl> DO NOT use this value directly.
-This value is used in some defined phase.
-This correspond to C<$Setting{option}-E<gt>{src}>.
+Change download base URL to I<donwload_from>.
+DEGAULT: http://jaist.dl.sourceforge.net/sourceforge/clamav
 
 =item -d I<download_to> | --dst I<download_to>
--d=I<download_to> | --dst=I<download_to>
 
-Specify a temporary directory to save download file as I<download_to>.
-Default value is some alphanumeric strings at random
-in your system temporary directory.
-Default directory will be removed before clamav-update.pl finish.
-
-B<clamav-update.pl> DO NOT use this value directly.
-This value is used in some defined phase. 
-This correspond to C<$Setting{option}-E<gt>{dst}>.
+Change directory of destination to I<donwload_from>.
+DEFAULT: Random named directory under system temporary directory.
 
 =item -n I<package_name> | --name I<package_name>
- -n=I<package_name> | --name=I<package_name>
 
-Specify I<package_name> as package name of software.
-Default value is clamav.
-
-B<clamav-update.pl> DO NOT use this value directly.
-This value is used in some defined phase.
-This correspond to C<$Setting{option}-E<gt>{name}>.
+Change package name to I<package_name>.
+DEFAULT: clamav
 
 =item -e I<package_extention> | --ext I<package_extention>
- -e=I<package_extention> | --ext=I<package_extention>
- 
-Specify I<package_extention> as suffix of an archive of the software.
-Default value is tar.gz .
 
-B<clamav-update.pl> DO NOT use this value directly.
-This value is used in some defined phase.
-This correspond to C<$Setting{option}-E<gt>{ext}>.
+Change package file extention to I<package_extention>.
+DEFAULT: tar.gz
 
-=item --limit-version I<version_number> | --limit-version=I<version_number>
+=item --limit-version I<version_number>
 
-Specify upper limit of version I<version_number>.
-B<clamav-update.pl> doesn't update I<version_number> or higher.
-Default value is undefined. It means unlimited.
+Change version that is limmited update to I<version_number>.
+DEFAULT: NONE
 
-This correspond to C<$Setting{option}-E<gt>{limit}-E<gt>{version}>.
+=item --limit-action I<phase_name>
 
-=item --limit-action I<phase_name> | --limit-action=I<phase_name>
+Change phase name for actions when update is limited to I<phase_name>.
+DEFAULT: NONE
 
-If B<clamav-update.pl> don't update software because of
-its upper limit of version, B<clamav-update.pl> execute phase.
-Default value is undefined. It means no action.
-
-=item --option I<name>=I<value> | --option=I<name>=I<value>
-
-Change value of C<$Setting{option}-E<gt>{I<name>}> to I<value>.
-This treats as changing configuration file temporally.
-If slash "/" character is included in name,
-name is treated as path.
-For example:
-
-  clamav-update.pl --option one/two/three=four ...
-
-It means that
-
-  $Setting{option}->{one}->{two}->{three} = 'four';
-
-This option configuration is overwrote by other directly option.
-For example, if you execute following command line:
-
-  clamav-update.pl --src download_from1 --option src=download_from2 ...
-
-B<clamav-update.pl> download from I<download_from1>.
-Because this is equiv to situation that
-you have bellow line in configuration file:
-
-  $Setting{option}->{src} = 'download_from2';
-
-and execute following command line:
-
-  clamav-update.pl --src download_from1 ...
 
 =back
 
@@ -1070,7 +949,7 @@ GetOptions(
 		PrepareLogging();
 		print <<EOF;
 $Version
-Copyright (C) 2006-2009 OKAMURA Yuji, All rights reserved.
+Copyright (C) 2006-2007 OKAMURA Yuji, All rights reserved.
 This is free software; see the source for copying conditions. There is NO 
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 EOF
@@ -1084,24 +963,6 @@ EOF
 	'e|ext=s'			=> \$Option{ext},
 	'limit-version=s'	=> \$Option{limit}->{version},
 	'limit-action=s'	=> \$Option{limit}->{action},
-	'option=s'			=> sub {
-		my	($namePath, $value) = split(/=/, $_[1], 2);
-		my	@namePath = split(/\//, $namePath);
-		my	$cur = $Setting{option};
-		my	$last = pop @namePath;
-		my	$history = '$Setting{option}';
-
-		foreach my $name (@namePath) {
-			$history .= '->{\''.$name.'\'}';
-			$cur->{$name} = {}	unless (exists $cur->{$name});
-			unless (ref($cur->{$name}) eq 'HASH') {
-				printf STDERR "%s isn't a hash reference.\n", $history;
-				exit $ErrorCode{arguments};
-			}
-			$cur = $cur->{$name};
-		}
-		$cur->{$last} = $value;
-	},
 ) or pod2usage($ErrorCode{arguments});
 
 
@@ -1200,66 +1061,18 @@ if (&{$Setting{version}->{compare}}($CurrentVersion, $LatestVersion) < 0) {
 # 終了処理
 END {
 	Log 'info', 'Finish clamav-update.pl --config %s', GetOptionValue('config');
-	CloseLog();
+	closelog()	if ($SyslogOpened);
 }
 
 #===============================================================================
 
-=head1 SEE ALSO
-
-Reference of Configuration: L<http://clamav-update.sourceforge.jp/docs/clamav-update-2/chapter2.html#B-3>
-
 =head1 CHANGE LOG
 
 =over 4
 
-=item v2.2.7
-
-* Fix ticket #21446
-
-=item v2.2.6
-
-* $Setting{option}->{src} came to be able to describe a more complex download origin as a hush.
-
-=item v2.2.5
-
-* Support redirection response from web server.
-
-=item v2.2.4
-
- * The function PhaseSpecifier4ClamavUpdate is improved for FreeBSD 6.2.
- * The function PhaseSpecifier4PkgOnDmg is improved to attach dmg file to unique
-   mount point.
-
-=item v2.2.3
-
- * Update POD based fu7mu4's translation.
- * Update english comments based fu7mu4's translation.
-
-=item v2.2.2
-
- * The problem that warnning messages of Perl are outputted
-   when the version of SYSLOG is new is fixed.
-
-=item v2.2.1
-
- * When log destination is GLOB, restrain the buffering.
- * When log destination is GLOB, close it explicitly.
- * Argument of find command in the install phase of
-   PhaseSpecifier4ClamAV4ClamXav was fixed.
-
-=item v2.2
-
- * Add option named "option"
-
-=item v2.1.1
-
- * install.sh problems are fixed.
- * All v1.x setting description are changed for v2.x
-
 =item v2.1
 
- * Add new feature "update limitting".
+ * Add new feature "update limitting". 
  * Add new optinos description to POD.
  * Improve build-in phase specifier functions.
    Now you can use PhaseSpecifier4ClamavUpdate on the system which use GNU
@@ -1306,8 +1119,6 @@ Initial version.
 
 OKAMURA Yuji E<lt>okamura@users.sourceforge.jpE<gt>
 
-Manual translator: fu7mu4
-
 =cut
 
 __END__;
