@@ -4,10 +4,10 @@
 debug=0
 verbose=0
 
-srcdir=`dirname $0`
-tempfoo=`basename $0`
-tempfile1=`mktemp -t ${tempfoo}` || exit 1
-tempfile2=`mktemp -t ${tempfoo}` || exit 1
+srcdir=`dirname "$0"`
+tempfoo=`basename "$0"`
+tempfile1=`mktemp .${tempfoo}.XXXXXX` || exit 1
+tempfile2=`mktemp .${tempfoo}.XXXXXX` || exit 1
 
 Prefix=/usr/local
 ClamavPrefix=/usr/local
@@ -499,7 +499,7 @@ fi
 
 if [ $verbose -gt 0 ]; then
 	cat <<EOF
----- Varigables ----
+---- Variables ----
 preifx: $Prefix
 clamavPrefix: $ClamavPrefix
 UsingClamd: $UsingClamd
@@ -515,7 +515,7 @@ fi
 
 
 #### Paramaters Check ####
-if expr "$Prefix" : '^/' > /dev/null; then
+if expr "$Prefix" : '/' > /dev/null; then
 	Prefix=`normalizeDir "$Prefix"`
 else
 	echo "Use absolute path for --prefix option: $Prefix" 1>&2
@@ -532,7 +532,7 @@ elif [ \! \( -d "$Prefix/bin" -a -d "$Prefix/etc" \) ]; then
 	exit 3
 fi
 
-if expr "$Prefix" : '^/' > /dev/null; then
+if expr "$ClamavPrefix" : '/' > /dev/null; then
 	ClamavPrefix=`normalizeDir "$Prefix"`
 else
 	echo "Use absolute path for --clamav-prefix option: $ClamavPrefix" 1>&2
@@ -578,17 +578,17 @@ if [ "$Prefix" != '/usr/local/clamXav' ]; then
 		echo "\$Setting{environment}->{PATH} = '/bin:/sbin:/usr/bin:/usr/sbin:$qtPrefix/bin';" >> "$tempfile1"
 	fi
 	if [ "$Prefix" == '/usr/local' ]; then
-		echo "\$Setting{phase}->{specifier] = \&PhaseSpecifier4ClamavUpdate;" >> "$tempfile1"
+		echo "\$Setting{phase}->{specifier} = \&PhaseSpecifier4ClamavUpdate;" >> "$tempfile1"
 	else
 		cat <<EOF >> "$tempfile1"
 \$Setting{phase}->{specifier} = sub {
 	PhaseSpecifier4ClamAV4ClamXav();
 
 	\$Phase{install}->{method} = [
-		[qw(install -C -o root -g root -m 0755 clamav-update.pl),
+		[qw(install -bp -o root -g root -m 0755 clamav-update.pl),
 			'$qtPrefix/bin/clamav-update.pl'
 		)],
-		[qw(install -C -o root -g root -m 0664 clamav-update-update.conf),
+		[qw(install -bp -o root -g root -m 0664 clamav-update-update.conf),
 			'$qtPrefix/etc/clamav-update-update.conf'
 		)],
 	];
@@ -612,22 +612,22 @@ if [ -f "$tempfile1" ]; then
 	fi
 
 	if [ $verbose -gt 0 ]; then
-		echo "install -Cb -o root -g \"$AdminGroup\" -m 0664 \"$tempfile1\" \"/etc/clamav-update-update.conf\""
+		echo "install -bp -o root -g \"$AdminGroup\" -m 0664 \"$tempfile1\" \"/etc/clamav-update-update.conf\""
 	fi
 	if [ $debug -gt 0 ]; then
 		view "$tempfile1"
 	else
-		install -Cb -o root -g "$AdminGroup" -m 0664 "$tempfile1" "/etc/clamav-update-update.conf"
+		install -bp -o root -g "$AdminGroup" -m 0664 "$tempfile1" "/etc/clamav-update-update.conf"
 	fi
 	rm "$tempfile1"
 fi
 
 #--- Install clamav-update.pl ---#
 if [ $verbose -gt 0 ]; then
-	echo "install -Cb -o root -g \"$AdminGroup\" -m 0755 \"$srcdir/clamav-update.pl\" \"$Prefix/bin/clamav-update.pl\""
+	echo "install -bp -o root -g \"$AdminGroup\" -m 0755 \"$srcdir/clamav-update.pl\" \"$Prefix/bin/clamav-update.pl\""
 fi
 if [ $debug -eq 0 ]; then
-	install -Cb -o root -g "$AdminGroup" -m 0755 "$srcdir/clamav-update.pl" "$Prefix/bin/clamav-update.pl"
+	install -bp -o root -g "$AdminGroup" -m 0755 "$srcdir/clamav-update.pl" "$Prefix/bin/clamav-update.pl"
 fi
 
 #--- Install clamav-update.conf ---#
@@ -665,19 +665,19 @@ while fgrep '%PhaseSpecfier%' "$tempfile1" > /dev/null 2>&1; do
 done
 
 if [ $verbose -gt 0 ]; then
-	echo "install -Cb -o root -g \"$AdminGroup\" -m 0664 \"$tempfile1\" \"$Prefix/etc/clamav-update.conf\""
+	echo "install -bp -o root -g \"$AdminGroup\" -m 0664 \"$tempfile1\" \"$Prefix/etc/clamav-update.conf\""
 fi
 if [ $debug -gt 0 ]; then
 	view "$tempfile1"
 else
-	install -Cb -o root -g "$AdminGroup" -m 0664 "$tempfile1" "$Prefix/etc/clamav-update.conf"
+	install -bp -o root -g "$AdminGroup" -m 0664 "$tempfile1" "$Prefix/etc/clamav-update.conf"
 fi
 rm "$tempfile1"
 
 #--- Install clamav-update-update.conf ---#
 if [ $verbose -gt 0 ]; then
-	echo "install -Cb -o root -g \"$AdminGroup\" -m 0664 \"$srcdir/clamav-update-update.conf\" \"$Prefix/etc/clamav-update-update.conf\""
+	echo "install -bp -o root -g \"$AdminGroup\" -m 0664 \"$srcdir/clamav-update-update.conf\" \"$Prefix/etc/clamav-update-update.conf\""
 fi
 if [ $debug -eq 0 ]; then
-	install -Cb -o root -g "$AdminGroup" -m 0664 "$srcdir/clamav-update-update.conf" "$Prefix/etc/clamav-update-update.conf"
+	install -bp -o root -g "$AdminGroup" -m 0664 "$srcdir/clamav-update-update.conf" "$Prefix/etc/clamav-update-update.conf"
 fi
